@@ -29,9 +29,15 @@
 
 G_BEGIN_DECLS
 
-#define VTE_DRAW_SINGLE_WIDE_CHARACTERS	"ABCDEFGHIJKLMNOPQRSTUVWXYZ" \
+#define VTE_DRAW_SINGLE_WIDE_CHARACTERS	\
+					" !\"#$%&'()*+,-./" \
+					"0123456789" \
+					":;<=>?@" \
+					"ABCDEFGHIJKLMNOPQRSTUVWXYZ" \
+					"[\\]^_`" \
 					"abcdefghijklmnopqrstuvwxyz" \
-					"0123456789./+@&"
+					"{|}~" \
+					""
 #define VTE_DRAW_DOUBLE_WIDE_CHARACTERS 0x4e00, 0x4e8c, 0x4e09, 0x56db, 0x4e94,\
 					0xac00, 0xac01, 0xac04, 0xac08, 0xac10
 /* For Pango, we have to use CJK Ideographs alone. Otherwise, 'width'
